@@ -170,6 +170,8 @@ def get_jobs_from_namespace(
             continue
         container = containers[0]
         resources = container.get('resources', {}).get('limits', '')
+        if resources is None:
+            resources = {}
 
         status = pod_data.get('status', {})
         start_time = status.get('startTime', None)
